EctoFoundationDB.Exception.IncorrectTenancy exception (Ecto.Adapters.FoundationDB v0.7.1)
Copy Markdown View SourceThis exception is raised when there is a conflict in the tenant used.
This exception is raised when there is a conflict in the tenant used.