EctoFoundationDB.Sandbox (Ecto.Adapters.FoundationDB v0.7.1)

Copy Markdown View Source

A module for managing a sandbox FoundationDB cluster. This allows a developer to create a space under which it should be safe to write tests.

When using this module, it creates a directory in the project root called .erlfdb. It is safe to delete this directory when you no longer need it (e.g. after test execution)

See Testing with EctoFoundationDB for more.

Summary

Functions

checkin(repo, id)

@spec checkin(Ecto.Repo.t(), EctoFoundationDB.Tenant.id()) :: :ok

checkout(repo, id, options \\ [])

open_db(repo)