An experimental backend for EctoFDB multitenancy. It uses FDB's Tenants to guarantee that a given transaction cannot access keys from another tenant.
To use ManagedTenant, your database must be configured with
fdbcli --exec 'configure tenant_mode=required_experimental'
# or
fdbcli --exec 'configure tenant_mode=optional_experimental'
FDB's tenants are still an experimental feature, so EctoFDB's ManagedTenant must
also be considered experimental. For now, we recommend using EctoFoundationDB.Tenant.DirectoryTenant,
which is the default.