EctoFoundationDB.Exception.Unsupported exception (Ecto.Adapters.FoundationDB v0.7.1)
Copy Markdown View SourceThis exception is raised when the application uses an Ecto feature that is not supported by the FoundationDB Adapter.
This exception is raised when the application uses an Ecto feature that is not supported by the FoundationDB Adapter.