EctoFoundationDB.Versionstamp (Ecto.Adapters.FoundationDB v0.7.1)

Copy Markdown View Source

Versionstamping is a feature that allows you to create a unique identifier for a record that is guaranteed to be unique across all records in the database.

Please refer to the documentation for Repo.async_insert_all!/3.

Summary

Functions

embed_as(_)

Callback implementation for Ecto.Type.embed_as/1.

equal?(term1, term2)

Callback implementation for Ecto.Type.equal?/2.

from_binary(bin)

from_integer(int)

get(tx)

incomplete(user)

incomplete?(arg1)

next()

next(tx)

resolve(arg1, arg2)

to_integer(vs)